# Table of Contents

- [calculated-fields-in-surveys](<./calculated-fields-in-surveys.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Calculated Fields in Surveys](<./Calculated-Fields-in-Surveys.md>)
  - [Introduction](<./Calculated-Fields-in-Surveys/Introduction.md>)
  - [Configuring Calculated Fields](<./Calculated-Fields-in-Surveys/Configuring-Calculated-Fields.md>)
  - [Processing Answers in Calculated Fields](<./Calculated-Fields-in-Surveys/Processing-Answers-in-Calculated-Fields.md>)
  - [Writing Calculated Fields to Fact Sheets](<./Calculated-Fields-in-Surveys/Writing-Calculated-Fields-to-Fact-Sheets.md>)
  - [Examples](<./Calculated-Fields-in-Surveys/Examples.md>)
  - [Number Input Questions: Calculating the Sum of Answers](<./Calculated-Fields-in-Surveys/Number-Input-Questions-Calculating-the-Sum-of-Answers.md>)
  - [Single-Select Questions: Assigning Scores to Answers](<./Calculated-Fields-in-Surveys/Single-Select-Questions-Assigning-Scores-to-Answers.md>)
  - [Multiple-Select Questions: Assigning Scores to Answers](<./Calculated-Fields-in-Surveys/Multiple-Select-Questions-Assigning-Scores-to-Answers.md>)
  - [Text Input Questions: Assigning Scores If a Specific Text Is Found](<./Calculated-Fields-in-Surveys/Text-Input-Questions-Assigning-Scores-If-a-Specific-Text-Is-Found.md>)
  - [Assigning Weights to Questions](<./Calculated-Fields-in-Surveys/Assigning-Weights-to-Questions.md>)
  - [Was this page helpful?](<./Calculated-Fields-in-Surveys/Was-this-page-helpful.md>)
